# Fief client for Python

[![build](https://github.com/fief-dev/fief-python/workflows/Build/badge.svg)](https://github.com/fief-dev/fief-python/actions)
[![codecov](https://codecov.io/gh/fief-dev/fief-python/branch/main/graph/badge.svg)](https://codecov.io/gh/fief-dev/fief-python)
[![PyPI version](https://badge.fury.io/py/fief-client.svg)](https://badge.fury.io/py/fief-client)

## Installation

```
pip install fief-client
```

## License

MIT
